==> kdepim-addons_19.12.3.orig.tar.xz: kdepim-addons-19.12.3/plugins/messageviewerheaderplugins/enterpriseheaderstyleplugin/messageviewer_enterpriseheaderstyleplugin.json.cmake <==
{
    "KPlugin": {
        "Description": "This plugin defines a mail header style for enterprise.",
        "Description[ar]": "تحدّد هذه الملحقة نمط ترويسات بريد للشّركات.",
        "Description[ca@valencia]": "Aquest connector defineix un estil empresarial per a la capçalera del correu.",
        "Description[ca]": "Aquest connector defineix un estil empresarial per a la capçalera del correu.",
        "Description[en_GB]": "This plugin defines a mail header style for enterprise.",
        "Description[es]": "Este complemento define un estilo de encabezado de correo para empresarial.",
        "Description[et]": "See plugin võimaldab kasutada firmapäise stiili.",
        "Description[fi]": "Tällä liitännäisellä voit määrittää yrityksen viestiotsaketyylin.",
        "Description[fr]": "Ce module définit un style d'en-tête de message pour une entreprise.",
        "Description[gl]": "Este complemento define un estilo de cabeceira de correo para empresas.",
        "Description[ia]": "Iste plugin define un stilo de capite de eposta per interprisa.",
        "Description[it]": "Questa estensione definisce uno stile di intestazioni di tipo aziendale per la posta.",
        "Description[ko]": "이 플러그인은 기업식 헤더 스타일을 제공합니다.",
        "Description[nl]": "Deze plug-in definieert een e-mailheaderstijl voor bedrijven.",
        "Description[pl]": "Ta wtyczka określa wygląd nagłówka pocztowego dla firm.",
        "Description[pt]": "Este 'plugin' define um estilo de cabeçalhos dos e-mails para empresas.",
        "Description[pt_BR]": "Este plugin define um estilo de cabeçalhos de e-mails para empresas.",
        "Description[ru]": "Этот модуль определяет корпоративный стиль заголовков.",
        "Description[sk]": "Tento plugin definuje štýl mailovej hlavičky pre podnik.",
        "Description[sl]": "Ta vstavek določa poslovni slog glav sporočila.",
        "Description[sr@ijekavian]": "Овај прикључак дефинише стил пословног заглавља порука",
        "Description[sr@ijekavianlatin]": "Ovaj priključak definiše stil poslovnog zaglavlja poruka",
        "Description[sr@latin]": "Ovaj priključak definiše stil poslovnog zaglavlja poruka",
        "Description[sr]": "Овај прикључак дефинише стил пословног заглавља порука",
        "Description[sv]": "Insticksprogrammet definierar en brevhuvudstil för företag.",
        "Description[tr]": "Bu eklenti, kurumsal posta başlığı biçimi tanımlar.",
        "Description[uk]": "Цим додатком визначається стиль заголовка повідомлення для бізнес-середовищ.",
        "Description[x-test]": "xxThis plugin defines a mail header style for enterprise.xx",
        "Description[zh_CN]": "此插件定义了企业邮件头部样式。",
        "EnabledByDefault": "@KDEPIM_ENTERPRISE_BUILD@",
        "Name": "Enterprise Header Style",
        "Name[ar]": "نمط التّرويسات ”شركة“",
        "Name[ca@valencia]": "Estil de capçalera corporativa",
        "Name[ca]": "Estil de capçalera corporativa",
        "Name[de]": "Vorspann-Design „Grafisch“",
        "Name[en_GB]": "Enterprise Header Style",
        "Name[es]": "Estilo de encabezado empresarial",
        "Name[et]": "Ettevõtte päisestiil",
        "Name[fi]": "Yritysotsakkeiden tyyli",
        "Name[fr]": "Style d'en-tête entreprise",
        "Name[gl]": "Estilo de cabeceira de empresa",
        "Name[ia]": "Stilo de capite interprisa",
        "Name[it]": "Stile con intestazioni aziendali",
        "Name[ko]": "기업식 헤더 스타일",
        "Name[nl]": "Stijl met headers van de onderneming",
        "Name[pl]": "Firmowe nagłówki",
        "Name[pt]": "Estilo de Cabeçalho Empresarial",
        "Name[pt_BR]": "Estilo de cabeçalho Empresarial",
        "Name[ru]": "Корпоративный стиль заголовков",
        "Name[sk]": "Podnikový štýl hlavičiek",
        "Name[sl]": "Slog s poslovnimi glavami",
        "Name[sr@ijekavian]": "пословни стил заглавља",
        "Name[sr@ijekavianlatin]": "poslovni stil zaglavlja",
        "Name[sr@latin]": "poslovni stil zaglavlja",
        "Name[sr]": "пословни стил заглавља",
        "Name[sv]": "Företagsrubrikstil",
        "Name[tr]": "Kurumsal Başlık Biçimi",
        "Name[uk]": "Корпоративний стиль заголовків",
        "Name[x-test]": "xxEnterprise Header Stylexx",
        "Name[zh_CN]": "企业信头风格",
        "ServiceTypes": [
            "MessageViewerHeaderStyle/Plugin"
        ],
        "Version": "1.0"
    },
    "X-KDE-MessageViewer-Header-Order": "1"
}

==> kdepim-addons-20.08.2.tar.xz: kdepim-addons-20.08.2/plugins/messageviewerheaderplugins/enterpriseheaderstyleplugin/messageviewer_enterpriseheaderstyleplugin.json.cmake <==
{
    "KPlugin": {
        "Description": "This plugin defines a mail header style for enterprise.",
        "Description[ar]": "تحدّد هذه الملحقة نمط ترويسات بريد للشّركات.",
        "Description[ca@valencia]": "Aquest connector defineix un estil empresarial per a la capçalera del correu.",
        "Description[ca]": "Aquest connector defineix un estil empresarial per a la capçalera del correu.",
        "Description[en_GB]": "This plugin defines a mail header style for enterprise.",
        "Description[es]": "Este complemento define un estilo de encabezado de correo para empresarial.",
        "Description[et]": "See plugin võimaldab kasutada firmapäise stiili.",
        "Description[fi]": "Tällä liitännäisellä voi asettaa yrityksen viestiotsaketyylin.",
        "Description[fr]": "Ce module définit un style d'en-tête de message pour une entreprise.",
        "Description[gl]": "Este complemento define un estilo de cabeceira de correo para empresas.",
        "Description[ia]": "Iste plugin define un stilo de capite de eposta per interprisa.",
        "Description[it]": "Questa estensione definisce uno stile di intestazioni di tipo aziendale per la posta.",
        "Description[ko]": "이 플러그인은 기업식 헤더 스타일을 제공합니다.",
        "Description[nl]": "Deze plug-in definieert een e-mailheaderstijl voor bedrijven.",
        "Description[pl]": "Ta wtyczka określa wygląd nagłówka pocztowego dla firm.",
        "Description[pt]": "Este 'plugin' define um estilo de cabeçalhos dos e-mails para empresas.",
        "Description[pt_BR]": "Este plugin define um estilo de cabeçalhos de e-mails para empresas.",
        "Description[ru]": "Этот модуль определяет корпоративный стиль заголовков.",
        "Description[sk]": "Tento plugin definuje štýl mailovej hlavičky pre podnik.",
        "Description[sl]": "Ta vstavek določa poslovni slog glav sporočila.",
        "Description[sr@ijekavian]": "Овај прикључак дефинише стил пословног заглавља порука",
        "Description[sr@ijekavianlatin]": "Ovaj priključak definiše stil poslovnog zaglavlja poruka",
        "Description[sr@latin]": "Ovaj priključak definiše stil poslovnog zaglavlja poruka",
        "Description[sr]": "Овај прикључак дефинише стил пословног заглавља порука",
        "Description[sv]": "Insticksprogrammet definierar en brevhuvudstil för företag.",
        "Description[tr]": "Bu eklenti, kurumsal posta başlığı biçimi tanımlar.",
        "Description[uk]": "Цим додатком визначається стиль заголовка повідомлення для бізнес-середовищ.",
        "Description[x-test]": "xxThis plugin defines a mail header style for enterprise.xx",
        "Description[zh_CN]": "此插件定义了企业邮件头部样式。",
        "EnabledByDefault": "@KDEPIM_ENTERPRISE_BUILD@",
        "Name": "Enterprise Header Style",
        "Name[ar]": "نمط التّرويسات ”شركة“",
        "Name[ca@valencia]": "Estil de capçalera corporativa",
        "Name[ca]": "Estil de capçalera corporativa",
        "Name[de]": "Vorspann-Design „Grafisch“",
        "Name[en_GB]": "Enterprise Header Style",
        "Name[es]": "Estilo de encabezado empresarial",
        "Name[et]": "Ettevõtte päisestiil",
        "Name[fi]": "Yritysotsakkeiden tyyli",
        "Name[fr]": "Style d'en-tête entreprise",
        "Name[gl]": "Estilo de cabeceira de empresa",
        "Name[ia]": "Stilo de capite interprisa",
        "Name[it]": "Stile con intestazioni aziendali",
        "Name[ko]": "기업식 헤더 스타일",
        "Name[nl]": "Stijl met headers van de onderneming",
        "Name[pl]": "Firmowe nagłówki",
        "Name[pt]": "Estilo de Cabeçalho Empresarial",
        "Name[pt_BR]": "Estilo de cabeçalho Empresarial",
        "Name[ru]": "Корпоративный стиль заголовков",
        "Name[sk]": "Podnikový štýl hlavičiek",
        "Name[sl]": "Slog s poslovnimi glavami",
        "Name[sr@ijekavian]": "пословни стил заглавља",
        "Name[sr@ijekavianlatin]": "poslovni stil zaglavlja",
        "Name[sr@latin]": "poslovni stil zaglavlja",
        "Name[sr]": "пословни стил заглавља",
        "Name[sv]": "Företagsrubrikstil",
        "Name[tr]": "Kurumsal Başlık Biçimi",
        "Name[uk]": "Корпоративний стиль заголовків",
        "Name[x-test]": "xxEnterprise Header Stylexx",
        "Name[zh_CN]": "企业信头风格",
        "ServiceTypes": [
            "MessageViewerHeaderStyle/Plugin"
        ],
        "Version": "1.0"
    },
    "X-KDE-MessageViewer-Header-Order": "1"
}
